/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.schema

import liquibase.integration.spring.SpringLiquibase
import metridoc.utils.Assert
import metridoc.utils.StringUtils
import org.springframework.core.io.DefaultResourceLoader

class SchemaPlugin {

    void liquibase(LinkedHashMap args) {
        def liquibase = this.getSpringLiquibase(args)
        liquibase.afterPropertiesSet()
    }

    SpringLiquibase getSpringLiquibase(LinkedHashMap args) {
        Assert.notNull(args.schema, "Liquibase needs a schema to run as provided by the parameter 'schema', it can either be a reference to an xml class o a class")
        Assert.notNull(args.dataSource, "A datasource must be provided for liquibase to build your schema using the parameter 'dataSource'")

        def liquibase = new SpringLiquibase()
        liquibase.dataSource = args.dataSource
        def schema = args.remove("schema")
        if (schema instanceof Class) {
            liquibase.resourceLoader = new GroovySchemaResource(args)
            liquibase.changeLog = "${schema.name}.xml" //adding the xml extension tricks liquibase into using the xml parser
        } else {
            liquibase.changeLog = args.schema
            liquibase.resourceLoader = new DefaultResourceLoader()
        }

        liquibase.contexts = StringUtils.EMPTY
        return liquibase
    }


}