/*
 * Copyright 2010 Trustees of the University of Pennsylvania Licensed under the
 * Educational Community License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License. You may
 * obtain a copy of the License at
 *
 * http://www.osedu.org/licenses/ECL-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an "AS IS"
 * BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package metridoc.plugins.schema.providers

import metridoc.plugins.schema.Schema

/**
 * Created by IntelliJ IDEA.
 * User: tbarker
 * Date: 7/7/11
 * Time: 3:59 PM
 */
class MySqlSchema implements Schema{

    Schema delegator

    def void addNotNullConstraints(String tableName, Map<String, String> columns) {
        columns.each {column, dataType ->
            addNotNullConstraint(tableName: tableName, columnName: column, columnDataType: dataType)
        }
    }

    def void createBasicTable(String tableName, Map<String, String> columns) {
        createTable(tableName: tableName) {
            column(name: "${tableName}_id", type: "BIGINT UNSIGNED", autoIncrement: true) {
                constraints(nullable: false, primaryKey: true)
            }
            columns.each {name, type ->
                column(name: name, type: type)
            }
            column(name: "load_time", type: "TIMESTAMP", defaultValueComputed: "CURRENT_TIMESTAMP") {
                constraints(nullable: false)
            }
        }
    }

    /**
     * creates a batch of single valued tables where the column name is equal to the table name
     *
     * @param columns
     */
    def void createOneColumnTables(Map columns) {
        columns.each {String column, String type ->
            createBasicTable(column, [column:type])
        }
    }

    def methodMissing(String name, args) {
        delegator.invokeMethod(name, args)
    }
}
